@@ -95,8 +95,8 @@ void (*_SLtt_color_changed_hook)(void);
 
 #if SLTT_HAS_NON_BCE_SUPPORT
 static int Bce_Color_Offset = 0;
-static int Can_Background_Color_Erase;
 #endif
+static int Can_Background_Color_Erase = 1;
 
 /* -1 means unknown */
 int SLtt_Has_Status_Line = -1;	       /* hs */
@@ -159,8 +159,8 @@ static Ansi_Color_Type Ansi_Color_Map[JMAX_COLORS] =
      {RGB(0, 1, 0, 1, 1, 1), SLTT_REV_MASK, NULL}
 };
 
-static char *Color_Fg_Str;
-static char *Color_Bg_Str;
+static char *Color_Fg_Str = "\033[3%dm";
+static char *Color_Bg_Str = "\033[4%dm";
 static char *Default_Color_Fg_Str = "\033[39m";
 static char *Default_Color_Bg_Str = "\033[49m";
 
@@ -190,7 +190,10 @@ static char *Curs_Up_Str;
 static char *Curs_F_Str;    /* RI termcap string */
 static char *Cursor_Visible_Str;    /* ve termcap string */
 static char *Cursor_Invisible_Str;    /* vi termcap string */
-
+#if 0
+static char *Start_Mouse_Rpt_Str;  /* Start mouse reporting mode */
+static char *End_Mouse_Rpt_Str;  /* End mouse reporting mode */
+#endif
 static char *Start_Alt_Chars_Str;  /* as */
 static char *End_Alt_Chars_Str;   /* ae */
 static char *Enable_Alt_Char_Set;  /* eA */
@@ -1766,9 +1769,10 @@ void SLtt_smart_puts(SLsmg_Char_Type *neww, SLsmg_Char_Type *oldd, int len, int
 			 { /* kanji match ? */
 			    if (!COLOR_EQS(*q, *p) || !COLOR_EQS(*(q+1), *(p+1)))
 			      {
-				 /* code is match ,but color is diff */
+				 /* code is match, but color is diff */
 				 *buf++ = *p++;
 				 *buf++ = *p++;
+				 q += 2;
 				 continue;
 			      }
 			    /* really match ! */
@@ -2079,7 +2083,10 @@ int SLtt_initialize (char *term)
    if (strcmp(t, "vt52") && (*t++ == 'v') && (*t++ == 't')
        && (ch = *t, (ch >= '1') && (ch <= '9'))) Vt100_Like = 1;
 
-   is_xterm = !strncmp (term, "xterm", 5);
+   is_xterm = ((0 == strncmp (term, "xterm", 5))
+	       || (0 == strncmp (term, "rxvt", 4))
+	       || (0 == strncmp (term, "Eterm", 5)));
+
    almost_vtxxx = (Vt100_Like
 		   || Linux_Console
 		   || is_xterm
