@@ -309,7 +309,7 @@ static unsigned char *regexp_looking_at (Re_Context_Type *ctx, register unsigned
 	     goto match_rest;
 
 	   case LEAST_ONCE | ANY_DIGIT:
-	     if ((str < estr) && ((*str > '9') || (*str < '0'))) return NULL;
+	     if ((str >= estr) || ((*str > '9') || (*str < '0'))) return NULL;
 	     str++;
 	     /* drop */
 	   case STAR | ANY_DIGIT:
